@@ -8,11 +8,12 @@ from peek_core_search._private.PluginNames import searchTuplePrefix
 
 @addTupleType
 class KeywordAutoCompleteTupleAction(TupleActionABC):
-    """ Keyword Auto Complete Tuple
+    """Keyword Auto Complete Tuple
 
     This tuple represents the details of a search result.
     """
-    __tupleType__ = searchTuplePrefix + 'KeywordAutoCompleteTupleAction'
+
+    __tupleType__ = searchTuplePrefix + "KeywordAutoCompleteTupleAction"
 
     #:  The property key to restrict to
     objectTypeId: Optional[int] = TupleField()
@@ -22,5 +23,3 @@ class KeywordAutoCompleteTupleAction(TupleActionABC):
 
     #:  The search string to search for
     searchString: str = TupleField()
-
-
